@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 use Regexp::Grammars;
 
-our $VERSION = '5.002';
+our $VERSION = '5.005';
 
 sub new {
     my ($class) = @_;
@@ -16,8 +16,8 @@ sub PT::Lang::X {
     my ($class) = @_;
 
     my $code = 'use strict;
-                use warnings;
-                use utf8;';
+        use warnings;
+        use utf8;';
 
     for my $element ( @{ $class->{Class}} ) {
         $code .= $element->X();
@@ -85,10 +85,21 @@ sub PT::Group::X {
     my ($class, $className) = @_;
 
     return (       $class->{Comment}
-                || $class->{Function}
                 || $class->{Parent}
                 || $class->{Packages}
-                || $class->{EmbedBlock} )->X($className);
+                || $class->{EmbedBlock}
+                || $class->{Function}
+                || $class->{NonSyntaxClass} )->X($className);
+}
+
+sub PT::NonSyntaxClass::X {
+    my ($class, $className) = @_;
+    my $nonSyntax = $class->{''};
+
+    print "SyntaxError", "\n";
+    print "===========", "\n";
+    print "ClassName: ", $className, "\n";
+    die "Error: $nonSyntax \n";
 }
 
 sub PT::Packages::X {
@@ -113,8 +124,8 @@ sub PT::PackageList::X {
 sub PT::Package::X {
     my ($class, $className) = @_;
 
-    return (        $class->{PackageWithConstructor}
-                 || $class->{PackageWithoutConstructor} )->X($className);
+    return (       $class->{PackageWithConstructor}
+                || $class->{PackageWithoutConstructor} )->X($className);
 }
 
 sub PT::PackageWithConstructor::X {
@@ -127,6 +138,7 @@ sub PT::PackageWithConstructor::X {
     if(exists $class->{ObjectParameters}) {
         my $objectParameters = $class->{ObjectParameters}->X($className);
         my $parameters;
+
         if(ref($objectParameters)) {
             $parameters = join(",", @{$objectParameters});
         } else {
@@ -180,14 +192,15 @@ sub PT::PackageName::X {
 
 sub PT::PackageWithoutConstructor::X {
     my ($class, $className) = @_;
-
     my $packageName = $class->{PackageName}->X($className);
+
     if(exists $class->{QW}) {
         my $qw = $class->{QW}->X($className);
 
         my $packageWithoutConstructor = "use " . $packageName . $qw . ";\n";
         return $packageWithoutConstructor;
     }
+
     my $packageWithoutConstructor = "use " . $packageName . ";\n";
     return $packageWithoutConstructor;
 }
@@ -220,17 +233,17 @@ sub PT::Constructor::X {
 }
 
 sub PT::Object::X {
-        my ($class, $className) = @_;
+    my ($class, $className) = @_;
 
-        my $object = $class->{''};
-        return $object;
+    my $object = $class->{''};
+    return $object;
 }
 
 sub PT::PackageDir::X {
-        my ($class, $className) = @_;
+    my ($class, $className) = @_;
 
-        my $packageDir = $class->{''};
-        return $packageDir;
+    my $packageDir = $class->{''};
+    return $packageDir;
 }
 
 sub PT::Parent::X {
@@ -267,9 +280,10 @@ sub PT::LineComment::X {
 
 sub PT::Function::X {
     my ($class, $className) = @_;
+
     my $functionName = $class->{FunctionName}->X($className);
     my $functionParamList = $class->{FunctionParamList}->X($className);
-    my $codeBlock = $class->{CodeBlock}->X($className);
+    my $codeBlock = $class->{CodeBlock}->X($className, $functionName);
 
     my $function = "\n sub " . $functionName . $functionParamList . $codeBlock;
     return $function;
@@ -277,14 +291,17 @@ sub PT::Function::X {
 
 sub PT::FunctionName::X {
     my ($class, $className) = @_;
+
     my $functionName = $class->{''};
     return $functionName;
 }
 
 sub PT::FunctionParamList::X {
     my ($class, $className) = @_;
+
     my @params = (       $class->{EmptyParamList}
                       || $class->{FunctionParams} )->X($className);
+
     my $functionParamList;
     $functionParamList = '( $class, ';
 
@@ -307,8 +324,8 @@ sub PT::FunctionParamList::X {
 }
 
 sub PT::CodeBlock::X {
-    my ($class, $className) = @_;
-    my $blocks = $class->{Blocks}->X($className);
+    my ($class, $className, $functionName) = @_;
+    my $blocks = $class->{Blocks}->X($className, $functionName);
     my $codeBlock = "{\n" . $blocks . "\n}";
     return $codeBlock;
 }
@@ -335,11 +352,11 @@ sub PT::Arg::X {
 }
 
 sub PT::Blocks::X {
-    my ($class, $className) = @_;
+    my ($class, $className, $functionName) = @_;
     my @blocks;
 
     for my $element ( @{$class->{Block}} ) {
-        push @blocks, $element->X($className);
+        push @blocks, $element->X($className, $functionName);
     }
 
     my $blocks = join("\n", @blocks);
@@ -347,17 +364,29 @@ sub PT::Blocks::X {
 }
 
 sub PT::Block::X {
-    my ($class, $className) = @_;
+    my ($class, $className, $functionName) = @_;
     my $block = (      $class->{IfElse}
                     || $class->{While}
                     || $class->{ForEach}
                     || $class->{For}
                     || $class->{EmbedBlock}
                     || $class->{Comment}
-                    || $class->{Statement} )->X($className);
+                    || $class->{Statement}
+                    || $class->{NonSyntaxFunction} )->X($className, $functionName);
     return $block;
 }
 
+sub PT::NonSyntaxFunction::X {
+    my ($class, $className, $functionName) = @_;
+    my $nonSyntax = $class->{''};
+
+    print "SyntaxError", "\n";
+    print "===========", "\n";
+    print "ClassName: ", $className, "\n";
+    print "FunctionName: ", $functionName, "\n";
+    die "Error: $nonSyntax \n";
+}
+
 sub PT::EmbedBlock::X {
     my ($class, $className) = @_;
 
@@ -381,6 +410,7 @@ sub PT::EmbeddedCode::X {
 
 sub PT::While::X {
     my ($class, $className) = @_;
+
     my $boolExpression = $class->{BoolExpression}->X($className);
     my $codeBlock = $class->{CodeBlock}->X($className);
 
@@ -390,6 +420,7 @@ sub PT::While::X {
 
 sub PT::ForEach::X {
     my ($class, $className) = @_;
+
     my $forEachVariableName = $class->{ForEachVariableName}->X($className);
     my $variableName = $class->{VariableName}->X($className);
     my $codeBlock = $class->{CodeBlock}->X($className);
@@ -402,12 +433,14 @@ sub PT::ForEach::X {
 
 sub PT::ForEachVariableName::X {
     my ($class, $className) = @_;
+
     my $variableName = $class->{VariableName}->X($className);
     return $variableName;
 }
 
 sub PT::For::X {
     my ($class, $className) = @_;
+
     my $variableName = $class->{VariableName}->X($className);
     my @forRange = $class->{ForRange}->X($className);
     my $codeBlock = $class->{CodeBlock}->X($className);
@@ -420,6 +453,7 @@ sub PT::For::X {
 
 sub PT::ForRange::X {
     my ($class, $className) = @_;
+
     my $lowerRange = $class->{LowerRange}->X($className);
     my $upperRange = $class->{UpperRange}->X($className);
 
@@ -429,6 +463,7 @@ sub PT::ForRange::X {
 
 sub PT::LowerRange::X {
     my ($class, $className) = @_;
+
     my $number = (     $class->{Number}
                     || $class->{VariableName}
                     || $class->{ArrayElement}
@@ -442,6 +477,7 @@ sub PT::LowerRange::X {
 
 sub PT::UpperRange::X {
     my ($class, $className) = @_;
+
     my $number = (     $class->{Number}
                     || $class->{VariableName}
                     || $class->{ArrayElement}
@@ -511,6 +547,7 @@ sub PT::IfElseIf::X {
 
 sub PT::If::X {
     my ($class, $className) = @_;
+
     my $boolExpression = $class->{BoolExpression}->X($className);
     my $codeBlock = $class->{CodeBlock}->X($className);
 
@@ -558,6 +595,7 @@ sub PT::BooleanExpression::X {
 
 sub PT::BoolOperatorExpression::X {
     my ($class, $className) = @_;
+
     my $boolOperator = $class->{BoolOperator}->X($className);
     my $boolOperand = $class->{BoolOperands}->X($className);
 
@@ -1272,7 +1310,9 @@ my $parser = qr {
     <objrule:  PT::ClassBlock>                 <LBrace> <ClassGroups> <RBrace>
     <objrule:  PT::ClassGroups>                <[Group]>+
 
-    <objrule:  PT::Group>                      <ws: (\s++)*> <Comment> | <Function> | <Parent> | <Packages> | <EmbedBlock>
+    <objrule:  PT::Group>                      <ws: (\s++)*> <Comment> | <Parent> | <Packages> | <EmbedBlock> | <Function> | <NonSyntaxClass>
+
+    <objtoken: PT::NonSyntaxClass>             \b.*?\b
 
     <objrule:  PT::Comment>                    [#] <LineComment> @
     <objtoken: PT::LineComment>                .*?
@@ -1305,7 +1345,9 @@ my $parser = qr {
     <objrule:  PT::CodeBlock>                  <LBrace> <Blocks> <RBrace>
     <objrule:  PT::Blocks>                     <[Block]>+
 
-    <objrule:  PT::Block>                      <IfElse> | <While> | <ForEach> | <For> | <EmbedBlock> | <Comment> | <Statement>
+    <objrule:  PT::Block>                      <IfElse> | <While> | <ForEach> | <For> | <EmbedBlock> | <Comment> | <Statement> | <NonSyntaxFunction>
+
+    <objtoken: PT::NonSyntaxFunction>          \b.*?\b
 
     <objrule:  PT::EmbedBlock>                 <TokenEmbedBlock> <EmbedCodeBlock>
     <objrule:  PT::EmbedCodeBlock>             <EmbedBegin> <EmbeddedCode> <EmbedEnd>
@@ -1373,6 +1415,7 @@ my $parser = qr {
     <objrule:  PT::KeyValue>                   <PairKey> <Colon> <PairValue>
     <objrule:  PT::PairKey>                    <Number> | <String> | <ClassFunctionReturn> | <FunctionReturn>
                                                 | <VariableName> | <EmbedBlock>
+
     <objrule:  PT::PairValue>                  <RealNumber> | <String> | <ClassFunctionReturn> | <FunctionReturn>
                                                 | <ArrayElement> | <HashElement> | <ArrayList> | <HashRef>
                                                 | <VariableName> | <EmbedBlock>
@@ -1419,6 +1462,7 @@ my $parser = qr {
     <objrule:  PT::CalcExpression>             <[CalcOperands]>+ % <[CalcOperator]>
     <objrule:  PT::CalcOperands>               <RealNumber> | <ScalarVariable> | <ArrayElement> | <HashElement> | <ClassAccessor>
                                                | <ClassFunctionReturn> | <FunctionReturn> | <EmbedBlock> | <ObjectFunctionCall>
+
     <objtoken: PT::CalcOperator>               <Plus> | <Minus> | <Multiply> | <Divide> | <Modulus> | <Exponent> | <EmbedBlock>
 
     <objrule:  PT::Return>                     <TokenReturn> <RHS>? <SemiColon>
